CameraFocus enum

마인드맵 카메라 포커스 옵션 / Mind map camera focus options

Inheritance
Available extensions

Values

rootNode → const CameraFocus

루트 노드 중심 / Focus on root node

center → const CameraFocus

캔버스 정중앙 / Focus on canvas center

fitAll → const CameraFocus

모든 노드가 보이도록 자동 조정 / Auto-fit all nodes

firstLeaf → const CameraFocus

첫 번째 리프 노드 / Focus on first leaf node

custom → const CameraFocus

커스텀 위치 (focusNodeId와 함께 사용) / Custom position (use with focusNodeId)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CameraFocus>
A constant List of the values in this enum, in order of their declaration.