MindMapData class

마인드맵 노드 데이터를 나타내는 클래스

Constructors

MindMapData({required String id, required String title, String description = '', List<MindMapData> children = const [], Color? color, Color? textColor, Color? borderColor, TextStyle? textStyle, Size? size, Map<String, dynamic>? customData})
const

Properties

borderColor Color?
노드의 테두리 색상 (null이면 기본 색상 사용)
final
children List<MindMapData>
하위 노드들
final
color Color?
노드의 색상 (null이면 기본 색상 사용)
final
customData Map<String, dynamic>?
사용자 정의 데이터
final
description String
노드의 상세 설명
final
hashCode int
The hash code for this object.
no setteroverride
id String
노드의 고유 식별자
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size?
노드의 크기 (null이면 레벨에 따른 기본 크기 사용)
final
textColor Color?
노드의 텍스트 색상 (null이면 기본 색상 사용)
final
textStyle TextStyle?
노드의 텍스트 스타일 (null이면 기본 스타일 사용)
final
title String
노드의 제목
final

Methods

copyWith({String? id, String? title, String? description, List<MindMapData>? children, Color? color, Color? textColor, Color? borderColor, TextStyle? textStyle, Size? size, Map<String, dynamic>? customData}) MindMapData
데이터 복사를 위한 copyWith 메소드
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override