captureKey property

GlobalKey<State<StatefulWidget>>? captureKey
final

Optional key to capture the full mind map canvas (wraps canvas in RepaintBoundary) to give the user the ability to save the mind map as an image

Implementation

final GlobalKey? captureKey;