NodeShape enum

노드의 모양을 정의하는 열거형

Inheritance
Available extensions

Values

roundedRectangle → const NodeShape

둥근 사각형 (기본값)

circle → const NodeShape

원형

rectangle → const NodeShape

사각형

diamond → const NodeShape

다이아몬드

hexagon → const NodeShape

육각형

ellipse → const NodeShape

타원

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NodeShape>
A constant List of the values in this enum, in order of their declaration.