InteractiveViewerOptions class
뷰어 옵션 설정 / Interactive viewer options
Constructors
- InteractiveViewerOptions({bool constrained = false, EdgeInsets boundaryMargin = const EdgeInsets.all(100), double minScale = 0.1, double maxScale = 3.0, bool enablePanAndZoom = true})
-
const
Properties
- boundaryMargin → EdgeInsets
-
final
- constrained → bool
-
final
- enablePanAndZoom → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxScale → double
-
final
- minScale → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited