MindMapLayout enum
마인드맵 레이아웃 방향을 정의하는 열거형
Values
- right → const MindMapLayout
-
오른쪽으로만 확장 (기본값)
- left → const MindMapLayout
-
왼쪽으로만 확장
- top → const MindMapLayout
-
위쪽으로만 확장
- bottom → const MindMapLayout
-
아래쪽으로만 확장
- radial → const MindMapLayout
-
모든 방향으로 확장 (원형)
- horizontal → const MindMapLayout
-
양쪽으로 확장 (좌우)
- vertical → const MindMapLayout
-
양쪽으로 확장 (상하)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MindMapLayout> - A constant List of the values in this enum, in order of their declaration.