MindMapStyle class
마인드맵의 전체적인 스타일을 정의하는 클래스 / Class that defines the overall style of the mind map
Constructors
-
MindMapStyle({MindMapType mindMapType = MindMapType.default_, MindMapLayout layout = MindMapLayout.right, NodeShape nodeShape = NodeShape.roundedRectangle, Color backgroundColor = const Color(0xFFF8FAFC), double levelSpacing = 240.0, double nodeMargin = 40.0, Color connectionColor = Colors.grey, double connectionWidth = 2.5, bool useCustomCurve = true, List<
Color> defaultNodeColors = const [Color(0xFF2563EB), Color(0xFF7C3AED), Color(0xFF059669), Color(0xFFDC2626), Color(0xFFF59E0B), Color(0xFF7C2D12), Color(0xFF6B21A8), Color(0xFF0EA5E9), Color(0xFF10B981), Color(0xFF8B5CF6), Color(0xFF06B6D4), Color(0xFFF97316)], TextStyle defaultTextStyle = const TextStyle(color: Colors.white, fontWeight: FontWeight.w600, height: 1.1), double rootNodeSize = 80.0, double primaryNodeSize = 60.0, double leafNodeSize = 45.0, Color selectionBorderColor = Colors.yellow, double selectionBorderWidth = 3.0, Duration animationDuration = const Duration(milliseconds: 500), Curve animationCurve = Curves.easeOutCubic, bool enableNodeShadow = true, Color nodeShadowColor = Colors.black26, double nodeShadowBlurRadius = 8.0, double nodeShadowSpreadRadius = 2.0, Offset nodeShadowOffset = const Offset(0, 4), bool enableAutoSizing = true, double minNodeWidth = 80.0, double maxNodeWidth = 200.0, double minNodeHeight = 40.0, EdgeInsets textPadding = const EdgeInsets.all(12.0), double maxCustomNodeWidth = 200.0, double maxCustomNodeHeight = 150.0, double minCustomNodeWidth = 60.0, double minCustomNodeHeight = 40.0, bool enableCustomNodeAutoSizing = true, Widget nodeBuilder(MindMapNode, bool, VoidCallback , VoidCallback , VoidCallback )?}) -
const
Properties
- animationCurve → Curve
-
노드 애니메이션 곡선 / Node animation curve
final
- animationDuration → Duration
-
노드 애니메이션 지속 시간 / Node animation duration
final
- backgroundColor → Color
-
배경색 / Background color
final
- connectionColor → Color
-
연결선 색상 / Connection line color
final
- connectionWidth → double
-
연결선 두께 / Connection line thickness
final
-
defaultNodeColors
→ List<
Color> -
기본 노드 색상들 (레벨별로 사용) / Default node colors (used by level)
final
- defaultTextStyle → TextStyle
-
기본 텍스트 스타일 / Default text style
final
- enableAutoSizing → bool
-
노드 자동 크기 조절 여부 / Whether auto-sizing for nodes is enabled
final
- enableCustomNodeAutoSizing → bool
-
커스텀 노드 크기 자동 조정 여부 / Whether to auto-adjust custom node size
final
- enableNodeShadow → bool
-
노드 그림자 활성화 여부 / Whether node shadow is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → MindMapLayout
-
마인드맵 레이아웃 방향 / Mind map layout direction
final
- leafNodeSize → double
-
리프 노드 크기 / Leaf node size
final
- levelSpacing → double
-
노드 간 수평 간격 / Horizontal spacing between nodes
final
- maxCustomNodeHeight → double
-
커스텀 노드 최대 높이 / Maximum height for custom nodes
final
- maxCustomNodeWidth → double
-
커스텀 노드 최대 너비 / Maximum width for custom nodes
final
- maxNodeWidth → double
-
최대 노드 너비 / Maximum node width
final
- minCustomNodeHeight → double
-
커스텀 노드 최소 높이 / Minimum height for custom nodes
final
- minCustomNodeWidth → double
-
커스텀 노드 최소 너비 / Minimum width for custom nodes
final
- mindMapType → MindMapType
-
마인드맵 타입 / Mind map type
final
- minNodeHeight → double
-
최소 노드 높이 / Minimum node height
final
- minNodeWidth → double
-
최소 노드 너비 / Minimum node width
final
- nodeBuilder → Widget Function(MindMapNode, bool, VoidCallback , VoidCallback , VoidCallback )?
-
노드 빌더 함수 / Node builder function
final
- nodeMargin → double
-
노드 간 수직 여백 / Vertical margin between nodes
final
- nodeShadowBlurRadius → double
-
노드 그림자 번짐 정도 / Node shadow blur radius
final
- nodeShadowColor → Color
-
노드 그림자 색상 / Node shadow color
final
- nodeShadowOffset → Offset
-
노드 그림자 오프셋 / Node shadow offset
final
- nodeShadowSpreadRadius → double
-
노드 그림자 퍼짐 정도 / Node shadow spread radius
final
- nodeShape → NodeShape
-
노드 모양 / Node shape
final
- primaryNodeSize → double
-
1차 자식 노드 크기 / Primary child node size
final
- rootNodeSize → double
-
루트 노드 크기 / Root node size
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionBorderColor → Color
-
노드 선택 시 테두리 색상 / Border color when node is selected
final
- selectionBorderWidth → double
-
노드 선택 시 테두리 두께 / Border thickness when node is selected
final
- textPadding → EdgeInsets
-
텍스트 패딩 / Text padding
final
- useCustomCurve → bool
-
연결선 스타일 (직선 또는 곡선) / Connection line style (straight or curved)
final
Methods
-
adjustCustomNodeSize(
Size originalSize, {String? title, int? level}) → Size - 커스텀 노드 크기를 제한 범위 내로 조정 / Adjust custom node size within limits
-
calculateNodeSize(
String text, int level, {TextStyle? customTextStyle}) → Size - 텍스트 내용에 따른 동적 노드 크기 계산 / Calculate dynamic node size based on text content
-
copyWith(
{MindMapType? mindMapType, MindMapLayout? layout, NodeShape? nodeShape, Color? backgroundColor, double? levelSpacing, double? nodeMargin, Color? connectionColor, double? connectionWidth, bool? useCustomCurve, List< Color> ? defaultNodeColors, TextStyle? defaultTextStyle, double? rootNodeSize, double? primaryNodeSize, double? leafNodeSize, Color? selectionBorderColor, double? selectionBorderWidth, Duration? animationDuration, Curve? animationCurve, bool? enableNodeShadow, Color? nodeShadowColor, double? nodeShadowBlurRadius, double? nodeShadowSpreadRadius, Offset? nodeShadowOffset, bool? enableAutoSizing, double? minNodeWidth, double? maxNodeWidth, double? minNodeHeight, EdgeInsets? textPadding, double? maxCustomNodeWidth, double? maxCustomNodeHeight, double? minCustomNodeWidth, double? minCustomNodeHeight, bool? enableCustomNodeAutoSizing, Widget nodeBuilder(MindMapNode, bool, VoidCallback , VoidCallback , VoidCallback )?}) → MindMapStyle - 스타일 복사를 위한 copyWith 메소드 / copyWith method for style copying
-
getActualNodeSize(
String text, int level, {Size? customSize, TextStyle? customTextStyle}) → Size - 노드의 실제 크기를 반환 (Size가 있으면 그것을 사용, 없으면 동적 계산) / Returns actual node size (use custom size if available, otherwise calculate dynamically)
-
getDefaultNodeColor(
int level) → Color - 노드 레벨에 따른 기본 색상을 반환 / Returns default color based on node level
-
getNodeSize(
int level) → double - 노드 레벨에 따른 크기를 반환 / Returns size based on node level
-
getTextSize(
int level) → double - 노드 레벨에 따른 텍스트 크기를 반환 / Returns text size based on node level
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited