MindMapWidget class
커스터마이징 가능한 마인드맵 위젯 / Customizable mind map widget
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MindMapWidget
Constructors
-
MindMapWidget({Key? key, required MindMapData data, MindMapStyle style = const MindMapStyle(), dynamic onNodeTap(MindMapData node)?, dynamic onNodeLongPress(MindMapData node)?, dynamic onNodeDoubleTap(MindMapData node)?, dynamic onNodeExpandChanged(MindMapData node, bool isExpanded)?, Size? canvasSize, InteractiveViewerOptions? viewerOptions, Size minCanvasSize = const Size(1200, 800), EdgeInsets canvasPadding = const EdgeInsets.all(300), bool isNodesCollapsed = false, double initialScale = 1.0, GlobalKey<
State< ? captureKey, CameraFocus cameraFocus = CameraFocus.rootNode, String? focusNodeId, Duration focusAnimation = const Duration(milliseconds: 300), EdgeInsets focusMargin = const EdgeInsets.all(20), NodeExpandCameraBehavior nodeExpandCameraBehavior = NodeExpandCameraBehavior.none})StatefulWidget> > -
const
Properties
- cameraFocus → CameraFocus
-
카메라 포커스 옵션 / Camera focus option
final
- canvasPadding → EdgeInsets
-
캔버스 여백 / Canvas padding
final
- canvasSize → Size?
-
캔버스 크기 (null이면 자동 계산) / Canvas size (auto-calculated if null)
final
-
captureKey
→ GlobalKey<
State< ?StatefulWidget> > -
Optional key to capture the full mind map canvas (wraps canvas in RepaintBoundary) to give the user the ability to save the mind map as an image
final
- data → MindMapData
-
마인드맵 데이터 / Mind map data
final
- focusAnimation → Duration
-
포커스 이동 애니메이션 지속시간 / Focus animation duration
final
- focusMargin → EdgeInsets
-
포커스할 때의 여백 / Margin when focusing
final
- focusNodeId → String?
-
포커스할 특정 노드 ID / Specific node ID to focus on
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialScale → double
-
Initial zoom scale for the mind map (1.0 = no zoom)
final
- isNodesCollapsed → bool
-
Whether nodes should be collapsed by default (false = open all nodes)
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minCanvasSize → Size
-
최소 캔버스 크기 / Minimum canvas size
final
- nodeExpandCameraBehavior → NodeExpandCameraBehavior
-
노드 확장 시 카메라 동작 / Camera behavior when expanding nodes
final
- onNodeDoubleTap → dynamic Function(MindMapData node)?
-
노드 더블 탭 콜백 / Node double tap callback
final
- onNodeExpandChanged → dynamic Function(MindMapData node, bool isExpanded)?
-
확장/축소 상태 변경 콜백 / Expand/collapse state change callback
final
- onNodeLongPress → dynamic Function(MindMapData node)?
-
노드 길게 누르기 콜백 / Node long press callback
final
- onNodeTap → dynamic Function(MindMapData node)?
-
노드 탭 콜백 / Node tap callback
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → MindMapStyle
-
마인드맵 스타일 / Mind map style
final
- viewerOptions → InteractiveViewerOptions?
-
뷰어 설정 / Interactive viewer options
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MindMapWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited