NodeExpandCameraBehavior enum
노드 확장 시 카메라 동작 옵션 / Camera behavior when expanding nodes
Values
- none → const NodeExpandCameraBehavior
-
카메라 이동 없음 / No camera movement
- focusClickedNode → const NodeExpandCameraBehavior
-
클릭한 노드로 포커스 / Focus on clicked node
- fitExpandedChildren → const NodeExpandCameraBehavior
-
새로 펼쳐진 자식 노드들을 모두 보이도록 조정 / Fit all newly expanded children
- fitExpandedSubtree → const NodeExpandCameraBehavior
-
펼쳐진 전체 서브트리를 보이도록 조정 / Fit entire expanded subtree
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NodeExpandCameraBehavior> - A constant List of the values in this enum, in order of their declaration.